def estimate_windchill(t, v):
    """
    Estimate the wind chill factor given the temperature and windspeed
    
    NOTE: This computation is valid only for temperatures between -45F and +45F 
          and for wind speeds between 3mph and 60mph.

    Parameters:
        t: The temperature in units of F (float)
        v: The wind speed in units of mph (float)
    """
    wci = t - 0.7 * v
    return wci


def compute_heatindex(t, hum):
    """
    Compute the heat index given temperature and humidity

    Parameters:
        t: The temperature in units of F (float)
        hum: The relative humidity in units of % (float)
    """
    a = -42.379
    b = 2.04901523
    c = 10.14333127
    d = -0.22475541
    e = -6.83783E-3
    f = -5.481717E-2
    g = 2.22874E-3
    h = 8.5282E-4
    i = -1.99E-6

    rh = hum/100

    hi = (a + (b * t) + (c * rh) + (d * t * rh) + \
        (e * t**2) + (f * rh**2) + (g * t**2 * rh) + \
        (h * t * rh**2) + (i * t**2 * rh**2))

    return hi


def read_data(columns, types={}, filename="data/wxobs20170821.txt"):
   """
   Read data from CU Boulder Weather Station data file

   Parameters:
      columns: A dictionary of column names mapping to column indices
      types: A dictionary of column names mapping to types to which
         to convert each column of data
      filename: The string path pointing to the CU Boulder Weather
            Station data file
   """

   # Initialize my data variable
   data = {}
   for column in columns:
      data[column] = []

   # Read and parse the data file
   with open(filename, 'r') as datafile:

      # Read the first three lines (header)
      for _ in range(3):
         datafile.readline()

      # Read and parse the rest of the file
      for line in datafile:
         split_line = line.split()
         for column in columns:
            i = columns[column]
            t = types.get(column, str)
            value = t(split_line[i])
            data[column].append(value)

   return data



def print_comparison(name, dates, times, original_data, computed_data):
    """
    Print a comparison of two time series (original and computed) of data

    Parameters:
        name: A string name for the data being compared (Display limited
            to 9 characters in length)
        dates: List of strings representing the dates for each data
        times: List of strings representing the time of day for each data
        original_data: List of original data (floats)
        computed_data: List of computed data (floats)
    """
    print('                      ORIGINAL    ESTIMATED')
    print(f'   DATE      TIME    {name.upper():>9}    {name.upper():>9}    DIFFERENCE')
    print('-------    ------    ---------    ---------    ----------')

    zip_data = zip(dates, times, original_data, computed_data)
    for date, time, orig, comp in zip_data:
        diff = orig - comp
        print(f'{date}    {time:>6}    {orig:9.6f}    {comp:9.6f}    {diff:10.6f}')


from distutils.core import setup

setup(
    name="newmysci",
    version="1.0.0",
    description="A sample package",
    author="Mhammed",
    author_email="jeddou.ehtp@gmail.com",
    packages=["newmysci"],
    install_requires=[],
)
